@@ -2,10 +2,11 @@ from .accuracy_validator import AccuracyValidator
 from .base_validator import BaseValidator
 from .deep_embedded_validator import DeepEmbeddedValidator
 from .diversity_validator import DiversityValidator
-from .entropy_diversity_validator import EntropyDiversityValidator
 from .entropy_validator import EntropyValidator
 from .error_validator import ErrorValidator
-from .knn_validator import ClusterValidator, KNNValidator
+from .im_validator import IMValidator
+
+# from .knn_validator import ClusterValidator, KNNValidator
 from .multiple_validators import MultipleValidators
 from .silhouette_score_validator import SilhouetteScoreValidator
 from .snd_validator import SNDValidator
